.. raw:: html

    <embed>
        <p align="center">
            <img width="300" src="https://github.com/yngtodd/nuclei/blob/master/img/nuclei.png">
        </p>
    </embed>

--------------------------

.. image:: https://img.shields.io/pypi/v/nuclei.svg
        :target: https://pypi.python.org/pypi/nuclei

.. image:: https://img.shields.io/travis/yngtodd/nuclei.svg
        :target: https://travis-ci.org/yngtodd/nuclei

.. image:: https://readthedocs.org/projects/nuclei/badge/?version=latest
        :target: https://nuclei.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/yngtodd/nuclei/shield.svg
     :target: https://pyup.io/repos/github/yngtodd/nuclei/
     :alt: Updates

======
Nuclei
======

2018 Kaggle Data Science Bowl

* Documentation: https://nuclei.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

